<?php
if ( !defined('ABSPATH') ) {
	exit; // Exit if accessed directly.
} 

if ( !class_exists('SWS_Store_Wide_Sale_Backend_Settings') ) {
	class SWS_Store_Wide_Sale_Backend_Settings {
		public function __construct() {
			$current = isset( $_GET['tab'] ) ? wc_clean($_GET['tab']) : 'global-settings';
			$tabs = array(
				'global-settings' => esc_html__('General Settings', 'storewide-sale'),
				'sale-settings' => esc_html__('Global Sale Settings', 'storewide-sale'),
				'control-settings' => esc_html__('Control Settings', 'storewide-sale'),
				'notification-settings'	  => esc_html__('Notification Settings', 'storewide-sale')
			);
			/**
			 * Custom tabs can be added.
			 * 
			 * @since 1.0.0
			 **/
			self::init_tabs( apply_filters('sws_setting_tabs', $tabs) );
			/**
			 * Custom tabs can be added.
			 * 
			 * @since 1.0.0
			 **/
			self::current_tab( apply_filters('sws_current_setting_tab', $current) );
		}
		public static function init_tabs( $tabs = array() ) {
			$current = isset( $_GET[ 'tab' ] ) ? wc_clean($_GET[ 'tab' ]) : 'global-settings';
			echo '<h5 class="nav-tab-wrapper">';
			foreach ( $tabs as $tab => $name ) {
				$class = ( $tab == $current ) ? 'nav-tab-active' : '';
				echo '<a class="nav-tab ' . esc_attr($class) . '" href="' . esc_url( admin_url('admin.php?page=storewide-sale&tab=' . esc_attr($tab) ) ) . '">' . esc_html($name) . '</a>';
			}
			echo '</h5>';
		}
		public static function current_tab( $current = 'global-settings' ) {
			switch ($current) {
				case 'global-settings':
					self::global_settings();
					break;
				case 'sale-settings':
					self::sale_settings();
					break;
				case 'control-settings':
					self::control_settings();
					break;
				case 'notification-settings':
					self::notification_settings();
					break; 
				default:
					self::global_settings();
					break;
			}
		}
		public static function global_settings() {
			?>
			<form action="options.php" method="post">
				<h1><?php esc_html_e('Storewide Sale - General Settings', 'storewide-sale'); ?></h1>
				<?php 
				settings_errors();
				settings_fields( 'storewide_sale_general_settings' );
				do_settings_sections('storewide_sale_general_settings'); 
				?>
				<table class="form-table">
					<tr>
						<th><label for="sws_storewide_sale_override"><?php esc_html_e('Override Individual Sale', 'storewide-sale'); ?></label></th>
						<td><?php $value = get_option('sws_storewide_sale_override'); ?>
							<p><label><input type="radio" name="sws_storewide_sale_override" value="nooverride" <?php checked('nooverride', $value); ?>>
							<i><?php esc_html_e('Do not override the sale applied at product level.', 'storewide-sale'); ?></i></label></p>
							<p><label><input type="radio" name="sws_storewide_sale_override" value="overrideminus" <?php checked('overrideminus', $value); ?>>
							<i><?php esc_html_e('Apply both sales applied at product level & with new storewide sale.', 'storewide-sale'); ?></i></label></p>
							<p><label><input type="radio" name="sws_storewide_sale_override" value="override" <?php checked('override', $value); ?>>
							<i><?php esc_html_e('Override the sale applied at product level with new storewide sale.', 'storewide-sale'); ?></i></label></p>
						</td>
					</tr>
					<tr>
						<th><label for="sws_storewide_sale_flash_override"><?php esc_html_e('Override Sales Flash HTML', 'storewide-sale'); ?></label></th>
						<td><?php $value = get_option('sws_storewide_sale_flash_override'); ?>
							<p><label><input type="checkbox" name="sws_storewide_sale_flash_override" value="yes" id="sws_storewide_sale_flash_override" <?php checked('yes', $value); ?>>
							<i><?php esc_html_e('Override sales flash HTML applied by theme.', 'storewide-sale'); ?></i></label></p>
						</td>
					</tr>
					<tr>
						<th><label for="sws_sale_flash_custom_html"><?php esc_html_e('Override Sales Flash Custom HTML', 'storewide-sale'); ?></label></th>
						<td><?php $value = get_option('sws_sale_flash_custom_html'); ?>
							<textarea name="sws_sale_flash_custom_html" id="sws_sale_flash_custom_html"><?php echo wp_kses_post($value); ?></textarea>
							<p><i><?php esc_html_e('Add sale flash HTML with {price} tag to display sale price/percentage value.', 'storewide-sale'); ?></i></p>
						</td>
					</tr>
					<tr>
						<th><label for="sws_storewide_sale_timer"><?php esc_html_e('Time Option', 'storewide-sale'); ?></label></th>
						<td><?php $value = get_option('sws_storewide_sale_timer'); ?>
							<select name="sws_storewide_sale_timer" class="regular-text">
								<option value="local" <?php selected('local', $value); ?>><?php esc_html_e('Local', 'storewide-sale'); ?></option>
								<option value="universal" <?php selected('universal', $value); ?>><?php esc_html_e('Universal', 'storewide-sale'); ?></option>
							</select>
						</td>
					</tr>
				</table>
				<?php submit_button(); ?>
			</form>
			<?php
		}
		public static function sale_settings() {
			?>
			<form action="options.php" method="post">
				<h1><?php esc_html_e('Storewide Sale - Price Settings', 'storewide-sale'); ?></h1>
				<?php 
				settings_errors();
				settings_fields( 'storewide_sale_settings' );
				do_settings_sections('storewide_sale_settings'); 
				?>
				<table class="form-table">
					<tr>
						<th><label for="sws_storewide_sale_enable"><?php esc_html_e('Enable Storewide Sale', 'storewide-sale'); ?></label></th>
						<td><?php $value = get_option('sws_storewide_sale_enable'); ?>
							<p><label><input type="checkbox" name="sws_storewide_sale_enable" value="yes" id="sws_storewide_sale_enable" <?php checked('yes', $value); ?>>
							<i><?php esc_html_e('Enable storewide sale.', 'storewide-sale'); ?></i></label></p>
						</td>
					</tr>
					<tr>
						<th><label for="sws_storewide_sale_amount"><?php esc_html_e('Sale Amount', 'storewide-sale'); ?></label></th>
						<td>
							<?php $value = get_option('sws_storewide_sale_amount'); ?>
							<input type="number" class="regular-text" name="sws_storewide_sale_amount" id="sws_storewide_sale_amount" value="<?php echo esc_attr( $value ); ?>" placeholder="<?php echo esc_html__( 'Enter sale amount', 'storewide-sale' ); ?>" step="any" min="0" />
						</td>
					</tr>
					<tr>
						<th><label for="sws_sale_amount_type"><?php esc_html_e('Sale Type', 'storewide-sale'); ?></label></th>
						<td>
							<?php $value = get_option('sws_sale_amount_type'); ?>
							<p><label><input type="radio" name="sws_sale_amount_type" id="sws_storewide_sale_amount" value="percentage" <?php checked('percentage', $value); ?> /> <?php echo esc_html__( 'Percentage (%)', 'storewide-sale' ); ?></label></p>
							<p><label><input type="radio" name="sws_sale_amount_type" id="sws_storewide_sale_amount" value="fixed" <?php checked('fixed', $value); ?> /> <?php echo esc_html__( 'Fixed', 'storewide-sale' ); ?></label></p>
						</td>
					</tr>
					<tbody class="sws_sale_price_dates_fields">
						<tr class="sws_sale_price_date_field">
							<th><label for="sws_sale_start_date"><?php esc_html_e('Sale Start Date', 'storewide-sale'); ?></label></th>
							<td>
								<?php $sale_price_dates_from = get_option('sws_sale_start_date'); ?>
								<input type="text" class="short regular-text" name="sws_sale_start_date" id="sws_sale_start_date" value="<?php echo esc_attr( $sale_price_dates_from ); ?>" placeholder="<?php echo esc_html__( 'placeholder', 'storewide-sale' ) . ' YYYY-MM-DD'; ?>" maxlength="10" pattern="<?php echo esc_attr( apply_filters( 'woocommerce_date_input_html_pattern', '[0-9]{4}-(0[1-9]|1[012])-(0[1-9]|1[0-9]|2[0-9]|3[01])' ) ); ?>" />
							</td>
						</tr>
						<tr class="sws_sale_price_date_field">
							<th><label for="sws_sale_end_date"><?php esc_html_e('Sale End Date', 'storewide-sale'); ?></label></th>
							<td>
								<?php $sale_price_dates_to = get_option('sws_sale_end_date'); ?>
								<input type="text" class="short regular-text" name="sws_sale_end_date" id="sws_sale_end_date" value="<?php echo esc_attr( $sale_price_dates_to ); ?>" placeholder="<?php echo esc_html__( 'placeholder', 'storewide-sale' ) . '  YYYY-MM-DD'; ?>" maxlength="10" pattern="<?php echo esc_attr( apply_filters( 'woocommerce_date_input_html_pattern', '[0-9]{4}-(0[1-9]|1[012])-(0[1-9]|1[0-9]|2[0-9]|3[01])' ) ); ?>" /></p>
							</td>
						</tr>
					</tbody>
					</table>
				<?php submit_button(); ?>
			</form>
			<?php
		}
		public static function control_settings() {
			?>
			<form action="options.php" method="post">
				<h1><?php esc_html_e('Storewide Sale - Control Settings', 'storewide-sale'); ?></h1>
				<?php 
				settings_errors();
				settings_fields( 'storewide_sale_control_settings' );
				do_settings_sections('storewide_sale_control_settings'); 
				?>
				<table class="form-table">
					<tr>
						<th>
							<label for="sws_sale_include_products"><?php esc_html_e('Include Products', 'storewide-sale'); ?></label>
						</th>
						<td>
							<?php $products = get_option('sws_sale_include_products'); ?>
							<select name="sws_sale_include_products[]" id="sws_sale_include_products"  class="wc-product-search regular-text" multiple>
							<?php 
							if ( !empty($products) ) {
								
								foreach ( $products as $product_id ) {
									if ( 'product' == get_post_type($product_id) || 'product_variation' == get_post_type($product_id) ) {
										echo '<option value="' . esc_attr($product_id) . '" selected="selected">' . esc_html( get_the_title($product_id) ) . '</option>';
									}
								}
							}
							?>
							</select>
							<p><i><?php esc_html_e('Choose products to include for the storewide sale.', 'storewide-sale'); ?></i></p>
						</td>
					</tr>
					<tr>
						<th>
							<label for="sws_sale_exclude_products"><?php esc_html_e('Exclude Products', 'storewide-sale'); ?></label>
						</th>
						<td>
							<?php $products = get_option('sws_sale_exclude_products'); ?>
							<select name="sws_sale_exclude_products[]" id="sws_sale_exclude_products"  class="wc-product-search regular-text" multiple>
							<?php 
							if ( !empty($products) ) {
								foreach ( $products as $key => $product_id ) {
									if ( 'product' == get_post_type($product_id) || 'product_variation' == get_post_type($product_id) ) {
										echo '<option value="' . esc_attr($product_id) . '" selected>' . esc_html( get_the_title($product_id) ) . '</option>';
									}
								}
							}
							?>
							</select>
							<p><i><?php esc_html_e('Choose products to exclude from storewide sale.', 'storewide-sale'); ?></i></p>
						</td>
					</tr>
					<tr>
						<th>
							<label for="sws_sale_include_categories"><?php esc_html_e('Include Product Categories', 'storewide-sale'); ?></label>
						</th>
						<td>
							<?php 
								$terms = get_terms( array(
									'taxonomy' => 'product_cat',
									'hide_empty' => false,
								) );
							?>
							<select name="sws_sale_include_categories[]" id="sws_sale_include_categories"  class="wc-enhanced-select regular-text" multiple>
							<?php 
							$value = get_option('sws_sale_include_categories');
							if ( !empty($terms) ) {
								foreach ( $terms as $key => $term ) {
									$selected = '';
									if ( !empty($value) && in_array($term->term_id, $value) ) {
										$selected = 'selected="selected"';
									}
									echo '<option value="' . esc_attr($term->term_id) . '" ' . esc_attr($selected) . '>' . esc_html($term->name) . '</option>';
								}
							}
							?>
							</select>
							<p><i><?php esc_html_e('Choose product categories to include for storewide sale.', 'storewide-sale'); ?></i></p>
						</td>
					</tr>
					<tr>
						<th>
							<label for="sws_sale_exclude_categories"><?php esc_html_e('Exclude Product Categories', 'storewide-sale'); ?></label>
						</th>
						<td>
							<?php 
								$terms = get_terms( array(
									'taxonomy' => 'product_cat',
									'hide_empty' => false,
								) );
							?>
							<select name="sws_sale_exclude_categories[]" id="sws_sale_exclude_categories"  class="wc-enhanced-select regular-text" multiple>
							<?php 
							$value = get_option('sws_sale_exclude_categories');
							if ( !empty($terms) ) {
								foreach ( $terms as $key => $term ) {
									$selected = '';
									if ( !empty($value) && in_array($term->term_id, $value) ) {
										$selected = 'selected="selected"';
									}
									echo '<option value="' . esc_attr($term->term_id) . '" ' . esc_attr($selected) . '>' . esc_html($term->name) . '</option>';
								}
							}
							?>
							</select>
							<p><i><?php esc_html_e('Choose product categories to exclude for storewide sale.', 'storewide-sale'); ?></i></p>
						</td>
					</tr>
					<tr>
						<th>
							<label for="sws_sale_include_tags"><?php esc_html_e('Include Product Tags', 'storewide-sale'); ?></label>
						</th>
						<td>
							<?php 
								$terms = get_terms( array(
									'taxonomy' => 'product_tag',
									'hide_empty' => false,
								) );
							?>
							<select name="sws_sale_include_tags[]" id="sws_sale_include_tags"  class="wc-enhanced-select regular-text" multiple>
							<?php 
							$value = get_option('sws_sale_include_tags');
							if ( !empty($terms) ) {
								foreach ( $terms as $key => $term ) {
									$selected = '';
									if ( !empty($value) && in_array($term->term_id, $value) ) {
										$selected = 'selected="selected"';
									}
									echo '<option value="' . esc_attr($term->term_id) . '" ' . esc_attr($selected) . '>' . esc_html($term->name) . '</option>';
								}
							}
							?>
							</select>
							<p><i><?php esc_html_e('Choose product tags to include for storewide sale.', 'storewide-sale'); ?></i></p>
						</td>
					</tr>
					<tr>
						<th>
							<label for="sws_sale_exclude_tags"><?php esc_html_e('Exclude Product Tags', 'storewide-sale'); ?></label>
						</th>
						<td>
							<?php 
								$terms = get_terms( array(
									'taxonomy' => 'product_tag',
									'hide_empty' => false,
								) );
							?>
							<select name="sws_sale_exclude_tags[]" id="sws_sale_exclude_tags"  class="wc-enhanced-select regular-text" multiple>
							<?php 
							$value = get_option('sws_sale_exclude_tags');
							if ( !empty($terms) ) {
								foreach ( $terms as $key => $term ) {
									$selected = '';
									if ( !empty($value) && in_array($term->term_id, $value) ) {
										$selected = 'selected="selected"';
									}
									echo '<option value="' . esc_attr($term->term_id) . '" ' . esc_attr($selected) . '>' . esc_html($term->name) . '</option>';
								}
							}
							?>
							</select>
							<p><i><?php esc_html_e('Choose product tags to exclude for storewide sale.', 'storewide-sale'); ?></i></p>
						</td>
					</tr>
				</table>
				<?php submit_button(); ?>
			</form>
			<?php
		}
		public static function notification_settings() {
			?>
			<form action="options.php" method="post">
				<h1><?php esc_html_e('Notification Settings', 'storewide-sale'); ?></h1>
				<?php 
				settings_errors();
				settings_fields( 'storewide_notification_settings' );
				do_settings_sections( 'storewide_notification_settings' );
				?>
				<table class="form-table">
					<tr>
						<th><label for="sws_storewide_notification_enable"><?php esc_html_e('Enable Sitewide Sale Notification', 'storewide-sale'); ?></label></th>
						<td><?php $value = get_option('sws_storewide_notification_enable'); ?>
							<p><label><input type="checkbox" name="sws_storewide_notification_enable" value="yes" id="sws_storewide_notification_enable" <?php checked('yes', $value); ?>>
							<i><?php esc_html_e('Enable storewide sale notification.', 'storewide-sale'); ?></i></label></p>
						</td>
					</tr>
					<tr>
						<th>
							<label for="sws_storewide_notification_text"><?php esc_html_e('Notification Content', 'storewide-sale'); ?></label>
						</th>
						<td>
							<?php $value = get_option('sws_storewide_notification_text'); ?>
							<input type="text" name="sws_storewide_notification_text" value="<?php esc_attr_e($value); ?>" id="sws_storewide_notification_text"  class="regular-text">
							<p><i><?php esc_html_e('Enter sale notification text, you can use the {start_date}, {end_date} & {amount} for dynamic data.', 'storewide-sale'); ?></i></p>
						</td>
					</tr>
					<tr>
						<th><label for="sws_storewide_notification_position"><?php esc_html_e('Notification Position', 'storewide-sale'); ?></label></th>
						<td>
							<?php $value = get_option('sws_storewide_notification_position'); ?>
							<p><label><input type="radio" name="sws_storewide_notification_position" value="sws-top" <?php checked('sws-top', $value); ?> /> <?php echo esc_html__( 'Page Top', 'storewide-sale' ); ?></label></p>
							<p><label><input type="radio" name="sws_storewide_notification_position" value="sws-bottom" <?php checked('sws-bottom', $value); ?> /> <?php echo esc_html__( 'Page Bottom', 'storewide-sale' ); ?></label></p>
						</td>
					</tr>
					<tr>
						<th>
							<label for="sws_storewide_notification_bg"><?php esc_html_e('Notification Background Color', 'storewide-sale'); ?></label>
						</th>
						<td>
							<?php $value = get_option('sws_storewide_notification_bg'); ?>
							<input type="text" name="sws_storewide_notification_bg" value="<?php esc_attr_e($value); ?>" id="sws_storewide_notification_bg"  class="regular-text sws-color-picker">
							<p><i><?php esc_html_e('choose the notification background color.', 'storewide-sale'); ?></i></p>
						</td>
					</tr>
					<tr>
						<th>
							<label for="sws_storewide_notification_color"><?php esc_html_e('Notification Font Color', 'storewide-sale'); ?></label>
						</th>
						<td>
							<?php $value = get_option('sws_storewide_notification_color'); ?>
							<input type="text" name="sws_storewide_notification_color" value="<?php esc_attr_e($value); ?>" id="sws_storewide_notification_color"  class="regular-text sws-color-picker">
							<p><i><?php esc_html_e('choose the notification font color.', 'storewide-sale'); ?></i></p>
						</td>
					</tr>
				</table>
				<?php submit_button(); ?>
			</form>
			<?php
		}
	}
	new SWS_Store_Wide_Sale_Backend_Settings();
}
