<?php
if ( !defined('ABSPATH') ) {
	exit;
}
if ( !class_exists('SWS_Storewide_Sale_Category') ) {
	class SWS_Storewide_Sale_Category {
		public function __construct() {
			add_action('product_cat_add_form_fields', array(__CLASS__, 'sws_term_fields'), 10);
			add_action('product_cat_edit_form_fields', array(__CLASS__, 'sws_term_edit_fields'));
			add_action('edited_product_cat', array(__CLASS__, 'sws_term_save_data'), 10, 2);
			add_action('create_product_cat', array(__CLASS__, 'sws_term_save_data'), 10, 2);
		}
		public static function sws_term_fields() {
			wp_nonce_field('sws_term_nonce', 'sws_term_nonce'); ?>
			<div>
				<div class="form-field">
					<label for="sws_storewide_sale_enable"><?php esc_html_e('Enable Storewide Sale', 'storewide-sale'); ?></label>
					<p><label><input type="checkbox" name="sws_storewide_sale_enable" value="yes" id="sws_storewide_sale_enable" />
					<i><?php esc_html_e('Enable storewide sale.', 'storewide-sale'); ?></i></label></p>
				</div>
				<div class="form-field">
					<label for="sws_storewide_sale_amount"><?php esc_html_e('Sale Amount', 'storewide-sale'); ?></label>
					<input type="number" class="regular-text" name="sws_storewide_sale_amount" id="sws_storewide_sale_amount" value="" placeholder="<?php echo esc_html__( 'Enter sale amount', 'storewide-sale' ); ?>" step="any" min="0" />
				</div>
				<div class="form-field">
					<label for="sws_sale_amount_type"><?php esc_html_e('Sale Type', 'storewide-sale'); ?></label>
					<p><label><input type="radio" name="sws_sale_amount_type" id="sws_storewide_sale_amount" value="percentage" /> <?php echo esc_html__( 'Percentage (%)', 'storewide-sale' ); ?></label></p>
					<p><label><input type="radio" name="sws_sale_amount_type" id="sws_storewide_sale_amount" value="fixed" /> <?php echo esc_html__( 'Fixed', 'storewide-sale' ); ?></label></p>
				</div>
				<div class="sws_sale_price_dates_fields">
					<div class="form-field sws_sale_price_date_field">
						<label for="sws_sale_start_date"><?php esc_html_e('Sale Start Date', 'storewide-sale'); ?></label>
						<input type="text" class="short regular-text" name="sws_sale_start_date" id="sws_sale_start_date" value="" placeholder="<?php echo esc_html__( 'placeholder', 'storewide-sale' ) . ' YYYY-MM-DD'; ?>" maxlength="10" pattern="<?php echo esc_attr( apply_filters( 'woocommerce_date_input_html_pattern', '[0-9]{4}-(0[1-9]|1[012])-(0[1-9]|1[0-9]|2[0-9]|3[01])' ) ); ?>" />
					</div>
					<div class="form-field sws_sale_price_date_field">
						<label for="sws_sale_end_date"><?php esc_html_e('Sale End Date', 'storewide-sale'); ?></label>
						<input type="text" class="short regular-text" name="sws_sale_end_date" id="sws_sale_end_date" value="" placeholder="<?php echo esc_html__( 'placeholder', 'storewide-sale' ) . '  YYYY-MM-DD'; ?>" maxlength="10" pattern="<?php echo esc_attr( apply_filters( 'woocommerce_date_input_html_pattern', '[0-9]{4}-(0[1-9]|1[012])-(0[1-9]|1[0-9]|2[0-9]|3[01])' ) ); ?>" /></p>
					</div>
				</div>
			</div>
			<?php
		}
		public static function sws_term_edit_fields( $term ) {
			$term_id = $term->term_id;
			wp_nonce_field('sws_term_nonce', 'sws_term_nonce'); 
			?>
			<tr>
				<th><label for="sws_storewide_sale_enable"><?php esc_html_e('Enable Storewide Sale', 'storewide-sale'); ?></label></th>
				<td><?php $value = get_term_meta($term_id, 'sws_storewide_sale_enable', true); ?>
					<p><label><input type="checkbox" name="sws_storewide_sale_enable" value="yes" id="sws_storewide_sale_enable" <?php checked('yes', $value); ?> />
					<i><?php esc_html_e('Enable storewide sale.', 'storewide-sale'); ?></i></label></p>
				</td>
			</tr>
			<tr>
				<th><label for="sws_storewide_sale_amount"><?php esc_html_e('Sale Amount', 'storewide-sale'); ?></label></th>
				<td>
					<?php $value = get_term_meta($term_id, 'sws_storewide_sale_amount', true); ?>
					<input type="number" class="regular-text" name="sws_storewide_sale_amount" id="sws_storewide_sale_amount" value="<?php echo esc_attr( $value ); ?>" placeholder="<?php echo esc_html__( 'Enter sale amount', 'storewide-sale' ); ?>" step="any" min="0" />
				</td>
			</tr>
			<tr>
				<th><label for="sws_sale_amount_type"><?php esc_html_e('Sale Type', 'storewide-sale'); ?></label></th>
				<td>
					<?php $value = get_term_meta($term_id, 'sws_sale_amount_type', true); ?>
					<p><label><input type="radio" name="sws_sale_amount_type" id="sws_storewide_sale_amount" value="percentage" <?php checked('percentage', $value); ?> /> <?php echo esc_html__( 'Percentage (%)', 'storewide-sale' ); ?></label></p>
					<p><label><input type="radio" name="sws_sale_amount_type" id="sws_storewide_sale_amount" value="fixed" <?php checked('fixed', $value); ?> /> <?php echo esc_html__( 'Fixed', 'storewide-sale' ); ?></label></p>
				</td>
			</tr>
			<tbody class="sws_sale_price_dates_fields">
				<tr class="sws_sale_price_date_field">
					<th><label for="sws_sale_start_date"><?php esc_html_e('Sale Start Date', 'storewide-sale'); ?></label></th>
					<td>
						<?php $sale_price_dates_from = get_term_meta($term_id, 'sws_sale_start_date', true); ?>
						<input type="text" class="short regular-text" name="sws_sale_start_date" id="sws_sale_start_date" value="<?php echo esc_attr( $sale_price_dates_from ); ?>" placeholder="<?php echo esc_html__( 'placeholder', 'storewide-sale' ) . ' YYYY-MM-DD'; ?>" maxlength="10" pattern="<?php echo esc_attr( apply_filters( 'woocommerce_date_input_html_pattern', '[0-9]{4}-(0[1-9]|1[012])-(0[1-9]|1[0-9]|2[0-9]|3[01])' ) ); ?>" />
					</td>
				</tr>
				<tr class="sws_sale_price_date_field">
					<th><label for="sws_sale_end_date"><?php esc_html_e('Sale End Date', 'storewide-sale'); ?></label></th>
					<td>
						<?php $sale_price_dates_to = get_term_meta($term_id, 'sws_sale_end_date', true); ?>
						<input type="text" class="short regular-text" name="sws_sale_end_date" id="sws_sale_end_date" value="<?php echo esc_attr( $sale_price_dates_to ); ?>" placeholder="<?php echo esc_html__( 'placeholder', 'storewide-sale' ) . '  YYYY-MM-DD'; ?>" maxlength="10" pattern="<?php echo esc_attr( apply_filters( 'woocommerce_date_input_html_pattern', '[0-9]{4}-(0[1-9]|1[012])-(0[1-9]|1[0-9]|2[0-9]|3[01])' ) ); ?>" /></p>
					</td>
				</tr>
			</tbody>
			<?php
		}
		public static function sws_term_save_data( $term_id, $term ) {
			if ( !isset( $_POST['sws_term_nonce'] ) || !wp_verify_nonce( wc_clean($_POST['sws_term_nonce']), 'sws_term_nonce' ) ) {
				return;
			}
			if ( !empty($_POST['sws_storewide_sale_enable']) ) {
				update_term_meta( $term_id, 'sws_storewide_sale_enable', wc_clean($_POST['sws_storewide_sale_enable']) );
			} else {
				update_term_meta( $term_id, 'sws_storewide_sale_enable', '');
			}
			if ( !empty($_POST['sws_storewide_sale_amount']) ) {
				update_term_meta( $term_id, 'sws_storewide_sale_amount', wc_clean($_POST['sws_storewide_sale_amount']) );
			} else {
				update_term_meta( $term_id, 'sws_storewide_sale_amount', '');
			}
			if ( !empty($_POST['sws_sale_amount_type']) ) {
				update_term_meta( $term_id, 'sws_sale_amount_type', wc_clean($_POST['sws_sale_amount_type']) );
			} else {
				update_term_meta( $term_id, 'sws_sale_amount_type', '');
			}
			if ( !empty($_POST['sws_sale_start_date']) ) {
				update_term_meta( $term_id, 'sws_sale_start_date', wc_clean($_POST['sws_sale_start_date']) );
			} else {
				update_term_meta( $term_id, 'sws_sale_start_date', '');
			}
			if ( !empty($_POST['sws_sale_end_date']) ) {
				update_term_meta( $term_id, 'sws_sale_end_date', wc_clean($_POST['sws_sale_end_date']) );
			} else {
				update_term_meta( $term_id, 'sws_sale_end_date', '');
			}
		}
	}
	new SWS_Storewide_Sale_Category();
}

