<?php
if ( !defined('ABSPATH') ) {
	exit; // Exit if accessed directly.
} 
if ( !class_exists('SWS_Store_Wide_Sale_Frontend') ) {
	class SWS_Store_Wide_Sale_Frontend {
		public static $sale;
		public function __construct() {
			self::$sale = array();
			add_filter( 'woocommerce_product_is_on_sale', array(__CLASS__, 'sws_is_on_sale'), 10, 2 );
			add_filter( 'woocommerce_product_get_price', array(__CLASS__, 'sws_dynamic_regular_price'), 0, 2 );
			add_filter( 'woocommerce_product_variation_get_price', array(__CLASS__, 'sws_dynamic_regular_price'), 0, 2 );
			add_filter( 'woocommerce_variation_prices_price', array(__CLASS__, 'sws_dynamic_regular_price'), 0, 2 );
			add_filter( 'woocommerce_get_variation_prices_hash', array(__CLASS__, 'sws_variationPricesHash'), 0, 1 );
			if ( 'yes' == get_option('sws_storewide_sale_flash_override') ) {
				add_filter(	'woocommerce_sale_flash', array(__CLASS__, 'sws_sale_flash'), 999, 3);
			}
			add_action( 'wp_footer', array(__CLASS__, 'sws_sale_notification') );
		}
		public static function sws_sale_flash( $html, $post, $product ) {
			$price = $product->get_price();
			$price = self::sws_flash_discount( $product );
			if ( empty($price) ) {
				return $html;
			}
			$sale_flash_html = get_option('sws_sale_flash_custom_html');
			$sale_flash_html = str_replace('{price}', $price, $sale_flash_html);
			if ( $sale_flash_html ) {
				$html = $sale_flash_html;
			} else {
				if ( !empty($html) ) {
					return '<span class="onsale">' . wp_kses_post( $price ) . '</span>';
				}
			}
			return $html;
		}
		public static function sws_sale_date_status( $product ) {
			$timer = get_option('sws_storewide_sale_timer');
			if ( 'universal' == $timer ) {
				$time = current_time('U');
			} else {
				$time = time();
			}
			if ( '' !== (string) $product->get_sale_price() && $product->get_regular_price() > $product->get_sale_price() ) {
				$on_sale = true;
				if ( $product->get_date_on_sale_from() && $product->get_date_on_sale_from()->getTimestamp() > $time ) {
					$on_sale = false;
				}
				if ( $product->get_date_on_sale_to() && $product->get_date_on_sale_to()->getTimestamp() < $time ) {
					$on_sale = false;
				}
			} else {
				$on_sale = false;
			}
			return $on_sale;
		}
		public static function sws_flash_discount( $product ) {
			$product_id = $product->get_id();
			if ( 'product_variation' == get_post_type( $product_id ) ) {
				$product_id = wp_get_post_parent_id($product_id);
			}
			$price = $product->get_price();
			$individual_Sale = get_option('sws_storewide_sale_override');
			if ( 'nooverride' == $individual_Sale && self::sws_sale_date_status($product) ) {
				return $price;
			}
			$amount = '';
			if ( !empty(self::$sale[$product_id]) ) {
				$flag = true;
				if ( !empty( self::$sale[$product_id]['category_id'] ) ) {
					$cat_id = absint(self::$sale[$product_id]['category_id']);
					$amount = get_term_meta( $cat_id, 'sws_storewide_sale_amount', true );
					$type = get_term_meta( $cat_id, 'sws_sale_amount_type', true );
					$sale_from = get_term_meta( $cat_id, 'sws_sale_start_date', true );
					$sale_to = get_term_meta( $cat_id, 'sws_sale_end_date', true );
					if ( !empty($amount) && !empty($type) && !empty($price) ) {
						if ( 'percentage' == $type ) {
							$amount = $amount . '%';
						} else {
							$amount = wc_price($amount);
						}
						return $amount;
					}
					$flag = false;
				}
				$amount = get_option('sws_storewide_sale_amount');
				$type = get_option('sws_sale_amount_type');
				if ( !empty($amount) && !empty($type) && $flag && !empty($price) ) {
					if ( 'percentage' == $type ) {
						$amount = $amount . '%';
					} else {
						$amount = wc_price($amount);
					}
				}
			}
			return $amount;
		}
		public static function sws_variationPricesHash( $hash ) {
			$hash[] = rand();
			return $hash;
		}
		public static function sws_is_on_sale( $on_sale, $product ) {
			$product_id = $product->get_id();
			if ( 'product_variation' == get_post_type( $product_id ) ) {
				$product_id = wp_get_post_parent_id($product_id);
			}
			if ( self::is_on_sale( $product_id ) ) {
				$on_sale = true;
			}
			return $on_sale;
		}
		public static function sws_dynamic_regular_price( $price, $product ) {
			$product_id = $product->get_id();
			if ( 'product_variation' == get_post_type( $product_id ) ) {
				$product_id = wp_get_post_parent_id($product_id);
			}
			if ( !self::is_on_sale( $product_id ) ) {
				return $price;
			}
			
			$individual_Sale = get_option('sws_storewide_sale_override');
			if ( 'nooverride' == $individual_Sale && self::sws_sale_date_status($product) ) {
				return $price;
			}
			if ( !empty(self::$sale[$product_id]) ) {
				$flag = true;
				if ( !empty( self::$sale[$product_id]['category_id'] ) ) {
					$cat_id = absint(self::$sale[$product_id]['category_id']);
					$amount = get_term_meta( $cat_id, 'sws_storewide_sale_amount', true );
					$type = get_term_meta( $cat_id, 'sws_sale_amount_type', true );
					$sale_from = get_term_meta( $cat_id, 'sws_sale_start_date', true );
					$sale_to = get_term_meta( $cat_id, 'sws_sale_end_date', true ); 
					if ( !empty($amount) && !empty($type) && !empty($price) ) {
						if ( 'override' == $individual_Sale ) {
							$price = $product->get_regular_price();
						}
						$price = self::calculate_price( $amount, $type, $price );
					}
					$flag = false;
					
				}
				$amount = get_option('sws_storewide_sale_amount');
				$type = get_option('sws_sale_amount_type');
				if ( !empty($amount) && !empty($type) && $flag && !empty($price) ) {
					if ( 'override' == $individual_Sale ) {
						$price = $product->get_regular_price();
					}
					$price = self::calculate_price( $amount, $type, $price );
				}
			}
			return $price;
		}
		public static function is_on_sale( $product_id ) {
			$timer = get_option('sws_storewide_sale_timer');
			if ( 'universal' == $timer ) {
				$time = current_time('U');
			} else {
				$time = time();
			}
			$flag = false;
			if ( 'product_variation' == get_post_type( $product_id ) ) {
				$product_id = wp_get_post_parent_id($product_id);
			}
			$product = wc_get_product($product_id);
			if ( 'nooverride' == get_option('sws_storewide_sale_override') && self::sws_sale_date_status( $product ) ) {
				return false;
			}
			$parent_id = '';
			$mixed_id = $product_id;
			if ( 'product_variation' == get_post_type( $product_id ) ) {
				$parent_id = wp_get_post_parent_id($product_id);
				$cat_ids = wc_get_product_cat_ids( $parent_id );
				$mixed_id = $product_id;
			} else {
				$cat_ids = wc_get_product_cat_ids( $product_id );
			}
			if ( !empty( $cat_ids ) ) {
				foreach ( $cat_ids as $cat_id ) {
					$sale_from = get_term_meta( $cat_id, 'sws_sale_start_date', true );
					$sale_to = get_term_meta( $cat_id, 'sws_sale_end_date', true ); 
					if ( 'yes' == get_term_meta( $cat_id, 'sws_storewide_sale_enable', true ) && !empty( get_term_meta( $cat_id, 'sws_storewide_sale_amount', true ) ) ) {
						$cat_flag = true;
						if ( !empty($sale_from) && strtotime($sale_from . '00:00:00') > $time ) {
							$cat_flag = false;
						}
						if ( !empty($sale_to) && strtotime($sale_to . '23:59:59') < $time ) {
							$cat_flag = false;
						}
						if ( $cat_flag ) {
							self::$sale[$product_id] = array(
								'amount' => get_term_meta( $cat_id, 'sws_storewide_sale_amount', true ),
								'category_id' => $cat_id
							);
							return true;
						}
					}
				}
			}
			if ( 'yes' == get_option('sws_storewide_sale_enable') ) {
				$in_prods = (array) get_option('sws_sale_include_products');
				$not_in_prods = (array) get_option('sws_sale_exclude_products');
				$in_cats = (array) get_option('sws_sale_include_categories');
				$not_in_cats = (array) get_option('sws_sale_exclude_categories');
				$in_tags = (array) get_option('sws_sale_include_tags');
				$not_in_tags = (array) get_option('sws_sale_exclude_tags');
				$sale_from = get_option('sws_sale_start_date');
				$sale_to = get_option('sws_sale_end_date'); 
				if ( ( !empty($in_prods) && in_array( $mixed_id, $in_prods ) ) || ( !empty($in_cats) && has_term( $in_cats, 'product_cat', $mixed_id ) ) || ( !empty($in_tags) && has_term( $in_tags, 'product_tag', $mixed_id ) ) ) {
					$flag = true;
				}
				if ( ( !empty($not_in_prods) && in_array( $mixed_id, $not_in_prods ) ) || ( !empty($not_in_cats) && has_term( $not_in_cats, 'product_cat', $mixed_id ) ) || ( !empty($not_in_tags) && has_term( $not_in_tags, 'product_tag', $mixed_id ) ) ) {
					$flag = false;
				}
				if ( !empty($sale_from) && strtotime($sale_from . '00:00:00') > $time ) {
					$flag = false;
				}
				if ( !empty($sale_to) && strtotime($sale_to . '23:59:59') < $time ) {
					$flag = false;
				}
				if ( $flag ) {

					self::$sale[$product_id] = array(
						'amount' => get_option( 'sws_storewide_sale_amount')
					);
					$flag = true;
				}
				return $flag;
			}
			return false;
		}
		public static function calculate_price( $amount, $type, $price ) {
			if ( empty($price) || empty($amount) ) {
				return $price;
			}
			if ( 'percentage' == $type ) {
				$price =  $price - $price * ( $amount / 100 );
			} else {
				$price =  $price - $amount;
			}
			return $price;
		}
		public static function sws_sale_notification() {
			$end_date = get_option('sws_sale_end_date');
			$current_date = date_create();
			$end_date = date_create($end_date);
			$diff = date_diff($current_date, $end_date);
			if ( intval($diff->format('%R%a')) < 0 ) {
				return;
			}
			$enable = get_option('sws_storewide_notification_enable');
			$text = get_option('sws_storewide_notification_text');
			if ( 'yes' == $enable && !empty($text) ) {
				$bg = get_option('sws_storewide_notification_bg');
				$bg = !empty($bg) ? $bg : '#d00';
				$color = get_option('sws_storewide_notification_color');
				$color = !empty($color) ? $color : '#fff';
				$position = get_option('sws_storewide_notification_position');
				?>
				<style>
					.sws_storewide_sale {
						position: fixed;
						top: 0;
						left: 0;
						right: 0;
						margin: 0 auto;
						text-align: center;
						overflow: hidden;
						background: <?php echo esc_html($bg); ?>;
						color: <?php echo esc_html($color); ?>;
						padding: 10px;
						z-index: 99999;
					}
					.sws_storewide_sale.sws-bottom {
						top: unset;
						bottom: 0;
					}
					.sws_storewide_sale.sws-top {
						bottom: unset;
						top: 0;
					}
				</style>
				<?php
				echo '<div class="sws_storewide_sale ' . esc_attr($position) . '">' . esc_html__($text, 'storewide-sale') . '</div>';
			}
		}
	}
	new SWS_Store_Wide_Sale_Frontend();
}
