<?php
/**
* Plugin Name: Storewide Sale
* Plugin URI: https://woocommerce.com/products/storewide-sale-for-woocommerce/
* Description: Apply storewide sale in one click settings.
* Version: 1.0.6
* Author: HighAddons
* Author URI: https://woocommerce.com/vendor/highaddons/
* Developer: HighAddons
* Developer URI: https://woocommerce.com/vendor/highaddons/
* Text Domain: storewide-sale
*
* Woo: 6664290:90c72f88f7aff7e80894c3865c2ce508
* WC requires at least: 3.5
* WC tested up to: 8.8.2
* 
* Copyright: © 2009-2024 WooCommerce.
* License: GNU General Public License v3.0
* License URI: http://www.gnu.org/licenses/gpl-3.0.html
**/
if ( !defined('ABSPATH') ) {
	exit; // Exit if accessed directly.
} 
if ( !defined('WC_SWS_DIR') ) {
	define('WC_SWS_DIR', plugin_dir_path(__FILE__));
}
if ( !defined('WC_SWS_URL') ) {
	define('WC_SWS_URL', plugin_dir_url(__FILE__));
}
if ( !class_exists('SWS_Store_Wide_Sale') ) {
	class SWS_Store_Wide_Sale {
		public function __construct() {
			/**
			 * Check if WooCommerce is installed and active.
			 * 
			 * @since 1.0.0
			 **/
			if ( ! function_exists( 'is_plugin_active_for_network' ) ) {
				require_once( ABSPATH . '/wp-admin/includes/plugin.php' );
			}
			if ( in_array('woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option('active_plugins'))) || is_plugin_active_for_network('woocommerce/woocommerce.php') ) {
				self::sws_init();
			} else {
				add_action('admin_notices', array(__CLASS__, 'sws_admin_notices'));
			}
			add_action('before_woocommerce_init', array(__CLASS__, 'sws_woocommerce_hpos_compatible' ) );
		}
		public static function sws_woocommerce_hpos_compatible() {
			if ( class_exists( '\Automattic\WooCommerce\Utilities\FeaturesUtil' ) ) {
				\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
			}
		}
		public static function sws_init() {
			/**
			 * Load language.
			 * 
			 * @since 1.0.0
			 **/
			if ( function_exists( 'load_plugin_textdomain' ) ) {
				load_plugin_textdomain('storewide-sale', false, dirname(plugin_basename(__FILE__)) . '/languages/');
			}
			if ( is_admin() ) {
				require_once WC_SWS_DIR . '/includes/class-sws-backend.php';
				require_once WC_SWS_DIR . '/includes/class-sws-category-settings.php';
			} else {
				require_once WC_SWS_DIR . '/includes/class-sws-frontend.php';
			}
		}
		public static function sws_admin_notices() {
			global $pagenow;
			if ( 'plugins.php' === $pagenow ) {
				$class = 'notice notice-error is-dismissible';
				$message = esc_html__('Storewide Sale For WooCommerce needs WooCommerce to be installed and active.', 'storewide-sale');
				printf('<div class="%1$s"><p>%2$s</p></div>', esc_html($class), esc_html($message));
			}
		}
	}
	new SWS_Store_Wide_Sale();
}
